Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(13)

Unified Diff: include/core/SkImageDecoder.h

Issue 322963002: hide SkBitmap::setConfig (Closed) Base URL: https://skia.googlesource.com/skia.git@master
Patch Set: Created 6 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « include/core/SkBitmap.h ('k') | include/gpu/GrSurface.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: include/core/SkImageDecoder.h
diff --git a/include/core/SkImageDecoder.h b/include/core/SkImageDecoder.h
index 950505a4b54638f8a288b3b7939157afded233df..f8e682baf0cc20971638933b733616473fbaa446 100644
--- a/include/core/SkImageDecoder.h
+++ b/include/core/SkImageDecoder.h
@@ -438,7 +438,7 @@ protected:
// helper function for decoders to handle the (common) case where there is only
// once choice available in the image file.
- bool chooseFromOneChoice(SkBitmap::Config config, int width, int height) const;
+ bool chooseFromOneChoice(SkColorType, int width, int height) const;
/* Helper for subclasses. Call this to allocate the pixel memory given the bitmap's
width/height/rowbytes/config. Returns true on success. This method handles checking
@@ -457,15 +457,15 @@ protected:
// 8 bits per component. Used for 24 bit if there is no alpha.
k32Bit_SrcDepth,
};
/** The subclass, inside onDecode(), calls this to determine the config of
the returned bitmap. SrcDepth and hasAlpha reflect the raw data of the
src image. This routine returns the caller's preference given
- srcDepth and hasAlpha, or kNo_Config if there is no preference.
+ srcDepth and hasAlpha, or kUnknown_SkColorType if there is no preference.
Note: this also takes into account GetDeviceConfig(), so the subclass
need not call that.
*/
- SkBitmap::Config getPrefConfig(SrcDepth, bool hasAlpha) const;
+ SkColorType getPrefColorType(SrcDepth, bool hasAlpha) const;
private:
Peeker* fPeeker;
« no previous file with comments | « include/core/SkBitmap.h ('k') | include/gpu/GrSurface.h » ('j') | no next file with comments »
@@ -457,15 +457,15 @@ protected:
k32Bit_SrcDepth,
};
- /** The subclass, inside onDecode(), calls this to determine the config of
+ /** The subclass, inside onDecode(), calls this to determine the colorType of
the returned bitmap. SrcDepth and hasAlpha reflect the raw data of the
src image. This routine returns the caller's preference given

Powered by Google App Engine
This is Rietveld 408576698